Machine Learning Workflow Framework
===================================

Installation
------------

::

    pip install tidml

Usage
-----

See ``examples`` and ``tests`` directories.

Development
-----------

::

    make install-dev

    make test

    make coverage

To-Do
-----

-  Multinomial Naive Bayes classifier example
-  Evaluation / Hyperparameter tuning
-  Incremental training (eg. partial\_fit)
-  Document, document, document...

Wish list
---------

-  CLI
-  Flask/Django/other microservice
-  Docker/other deployment
-  H2O.ai integration
